==> mono_2.6.7.orig.tar.gz: mono-2.6.7/mcs/class/System.ServiceModel/System.ServiceModel.Security/UserNamePasswordServiceCredential.cs <==
//
// UserNamePasswordServiceCredential.cs
//
// Author:
//	Atsushi Enomoto <atsushi@ximian.com>
//
// Copyright (C) 2005 Novell, Inc.  http://www.novell.com
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
using System;
using System.Collections.Generic;
using System.Security.Cryptography.X509Certificates;
using System.Web.Security;
using System.IdentityModel.Selectors;
using System.ServiceModel.Channels;
using System.ServiceModel.Description;
using System.ServiceModel.Security;
using System.ServiceModel.Security.Tokens;

namespace System.ServiceModel.Security
{
	public sealed class UserNamePasswordServiceCredential
	{
		internal UserNamePasswordServiceCredential ()
		{
		}

		MembershipProvider provider;
		TimeSpan lifetime = TimeSpan.FromMinutes (15);
		bool cache_tokens, include_win_groups = true;
		int max_cache_tokens = 0x80;
		UserNamePasswordValidator validator;
		UserNamePasswordValidationMode mode;

		[MonoTODO]
		public UserNamePasswordValidationMode UserNamePasswordValidationMode {
			get { return mode; }
			set { mode = value; }
		}

		[MonoTODO]
		public bool CacheLogonTokens {
			get { return cache_tokens; }
			set { cache_tokens = value; }
		}

		[MonoTODO]
		public TimeSpan CachedLogonTokenLifetime {
			get { return lifetime; }
			set { lifetime = value; }
		}

		[MonoTODO]
		public bool IncludeWindowsGroups {
			get { return include_win_groups; }
			set { include_win_groups = value; }
		}

		[MonoTODO]
		public int MaxCachedLogonTokens {
			get { return max_cache_tokens; }
			set { max_cache_tokens = value; }
		}

		public UserNamePasswordValidator CustomUserNamePasswordValidator {
			get { return validator; }
			set { validator = value; }
		}

		public MembershipProvider MembershipProvider {
			get { return provider; }
			set { provider = value; }
		}
	}
}

==> mono_4.2.1.102+dfsg2.orig.tar.gz: mono-4.2.1+dfsg2/mcs/class/System.ServiceModel/System.ServiceModel.Security/UserNamePasswordServiceCredential.cs <==
//
// UserNamePasswordServiceCredential.cs
//
// Author:
//	Atsushi Enomoto <atsushi@ximian.com>
//
// Copyright (C) 2005 Novell, Inc.  http://www.novell.com
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
using System;
using System.Collections.Generic;
using System.Security.Cryptography.X509Certificates;
using System.Web.Security;
using System.IdentityModel.Selectors;
using System.ServiceModel.Channels;
using System.ServiceModel.Description;
using System.ServiceModel.Security;
using System.ServiceModel.Security.Tokens;

namespace System.ServiceModel.Security
{
	public sealed class UserNamePasswordServiceCredential
	{
		internal UserNamePasswordServiceCredential ()
		{
		}

		MembershipProvider provider;
		TimeSpan lifetime = TimeSpan.FromMinutes (15);
		bool cache_tokens, include_win_groups = true;
		int max_cache_tokens = 0x80;
		UserNamePasswordValidator validator;
		UserNamePasswordValidationMode mode;

		internal UserNamePasswordServiceCredential Clone ()
		{
			return (UserNamePasswordServiceCredential) MemberwiseClone ();
		}

		[MonoTODO]
		public UserNamePasswordValidationMode UserNamePasswordValidationMode {
			get { return mode; }
			set { mode = value; }
		}

		[MonoTODO]
		public bool CacheLogonTokens {
			get { return cache_tokens; }
			set { cache_tokens = value; }
		}

		[MonoTODO]
		public TimeSpan CachedLogonTokenLifetime {
			get { return lifetime; }
			set { lifetime = value; }
		}

		[MonoTODO]
		public bool IncludeWindowsGroups {
			get { return include_win_groups; }
			set { include_win_groups = value; }
		}

		[MonoTODO]
		public int MaxCachedLogonTokens {
			get { return max_cache_tokens; }
			set { max_cache_tokens = value; }
		}

		public UserNamePasswordValidator CustomUserNamePasswordValidator {
			get { return validator; }
			set { validator = value; }
		}

		public MembershipProvider MembershipProvider {
			get { return provider; }
			set { provider = value; }
		}
	}
}
